## The problem

Briefly describe the issue you are experiencing (or feature you want to see added). If you received an error,
please include the error message!

## Steps to reproduce

Please also include the steps you took so we can try to reproduce the error!

## Screenshots

If you have any helpful screenshots or a file you tried to upload, please include them!

## Environment

* `snakebids` version (if applicable)
* Operating system (e.g. Ubuntu 20.04, Windows 10)